@@ -161,7 +161,8 @@ class Query(object):
 			startCursor = filters["cursor"]
 		if "endcursor" in filters and filters["endcursor"] and filters["endcursor"].lower() != "none":
 			endCursor = filters["endcursor"]
-		self.setCursor(startCursor, endCursor)
+		if startCursor or endCursor:
+			self.setCursor(startCursor, endCursor)
 		if "limit" in filters and str(filters["limit"]).isdigit() and int(filters["limit"]) > 0 and int(
 				filters["limit"]) <= 100:
 			self.limit(int(filters["limit"]))
@@ -337,9 +338,19 @@ class Query(object):
 			:param endCursor: The end cursor for this query.
 			:returns: Returns the query itself for chaining.
 		"""
-		assert isinstance(self.queries, QueryDefinition)
-		self.queries.startCursor = urlsafe_b64decode(startCursor.encode("ASCII")).decode("ASCII") if startCursor else None
-		self.queries.endCursor = urlsafe_b64decode(endCursor.encode("ASCII")).decode("ASCII") if endCursor else None
+		if isinstance(self.queries, list):
+			for query in self.queries:
+				assert isinstance(query, QueryDefinition)
+				if startCursor:
+					query.startCursor = urlsafe_b64decode(startCursor.encode("ASCII")).decode("ASCII")
+				if endCursor:
+					query.endCursor = urlsafe_b64decode(endCursor.encode("ASCII")).decode("ASCII")
+		else:
+			assert isinstance(self.queries, QueryDefinition)
+			if startCursor:
+				self.queries.startCursor = urlsafe_b64decode(startCursor.encode("ASCII")).decode("ASCII")
+			if endCursor:
+				self.queries.endCursor = urlsafe_b64decode(endCursor.encode("ASCII")).decode("ASCII")
 		return self
 
 
@@ -390,6 +401,20 @@ class Query(object):
 			q = self.queries[0]
 		return urlsafe_b64encode(q.currentCursor.encode("ASCII")).decode("ASCII") if q.currentCursor else None
 
+	def get_orders(self):
+		"""
+			Get the orders from this query.
+
+			:returns: The orders form this query as a list if there is no orders set it returns None
+		"""
+		if isinstance(self.queries, QueryDefinition):
+			q = self.queries
+		elif isinstance(self.queries, list):
+			q = self.queries[0]
+		else:
+			raise f"self.queries can only be from type 'QueryDefinition' or a list of 'QueryDefinition'"
+		return q.orders if q.orders else None
+
 	def getKind(self) -> str:
 		"""
 			:returns: the *current* kind of this query. This may not be the kind this query has been constructed with
@@ -590,6 +615,7 @@ class Query(object):
 			skelInstance.dbEntity = e
 			res.append(skelInstance)
 		res.getCursor = lambda: self.getCursor()
+		res.get_orders = lambda: self.get_orders()
 		return res
 
 	def iter(self):
@@ -672,4 +698,4 @@ class Query(object):
 		return res
 
 	def __repr__(self):
-		return "<db.Query on %s with queries %s>" % (self.kind, self.queries)
\ No newline at end of file
+		return "<db.Query on %s with queries %s>" % (self.kind, self.queries)
